@@ -17,11 +17,14 @@ github.com/xiyaowong/python-iotbot
 >>> @bot.on_event
 >>> def event(message: EventMsg):
 >>>     pass
+
+>>> if __name__ == '__main__':
+        bot.run()
 """
 
+from . import refine as refine_message  # 兼容旧版本，以后可能删除
 from .action import Action
 from .client import IOTBOT
-from .model import EventMsg
-from .model import FriendMsg
-from .model import GroupMsg
-from .model import model_map
+from .model import EventMsg, FriendMsg, GroupMsg
+
+__author__ = 'wongxy'
